summaryrefslogtreecommitdiffstats
path: root/libkdegames/kcarddialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commita13e26c2f1eb3c5be81acf4f571dd4bafac10199 (patch)
tree1f1d3e407ae668b1448847970b2f1b626083faf6 /libkdegames/kcarddialog.h
parent24c5cdc2737fe0044b11a12359606973eb93fc0b (diff)
downloadtdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.tar.gz
tdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdegames/kcarddialog.h')
-rw-r--r--libkdegames/kcarddialog.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdegames/kcarddialog.h b/libkdegames/kcarddialog.h
index e0681f5b..c3a0f018 100644
--- a/libkdegames/kcarddialog.h
+++ b/libkdegames/kcarddialog.h
@@ -104,11 +104,11 @@ public:
/**
* Constructs a card deck selection dialog.
*
* @param tqparent The tqparent widget of the dialog, if any.
* @param name The name of the dialog.
* @param flags Specifies whether the dialog is modal or not.
*/
- KCardDialog (TQWidget* tqparent = NULL,const char* name = NULL,
+ KCardDialog (TQWidget* parent = NULL,const char* name = NULL,
CardFlags flags = Both);
/**
* Destructs a card deck selection dialog.
@@ -126,7 +126,7 @@ public:
* @param carddir a reference to the directory name used as front of the
* cards. The directory contains the card images as 1.png to 52.png
*
* @param tqparent an optional pointer to the tqparent window of the dialog
*
* @param flags what to show
*
@@ -154,7 +154,7 @@ public:
*
* @return TQDialog::result().
*/
- static int getCardDeck(TQString &deck,TQString &carddir, TQWidget *tqparent=0,
+ static int getCardDeck(TQString &deck,TQString &carddir, TQWidget *parent=0,
CardFlags flags=Both, bool* randomDeck=0,
bool* randomCardDir=0, double* scale=0, KConfig* conf=0);
@@ -104,11 +104,11 @@ public:
* Constructs a card deck selection dialog.
*
- * @param tqparent The tqparent widget of the dialog, if any.
+ * @param parent The parent widget of the dialog, if any.
* @param name The name of the dialog.
* @param flags Specifies whether the dialog is modal or not.
@@ -126,7 +126,7 @@ public:
* cards. The directory contains the card images as 1.png to 52.png
*
- * @param tqparent an optional pointer to the tqparent window of the dialog
+ * @param parent an optional pointer to the parent window of the dialog
*
* @param flags what to show